@@ -1,8 +1,10 @@
 from TFGENZOO.flows.actnorm import Actnorm
-from TFGENZOO.flows.affine_coupling import (AffineCoupling, AffineCouplingMask,
-                                            LogScale)
+from TFGENZOO.flows.affine_coupling import AffineCoupling, AffineCouplingMask, LogScale
+from TFGENZOO.flows.flatten import Flatten
 from TFGENZOO.flows.flowbase import FactorOutBase, FlowComponent, FlowModule
 from TFGENZOO.flows.inv1x1conv import Inv1x1Conv, regular_matrix_init
+from TFGENZOO.flows.quantize import LogitifyImage
+from TFGENZOO.flows.squeeze import Squeeze
 
 __all__ = [
     "FactorOutBase",
@@ -14,4 +16,7 @@ __all__ = [
     "LogScale",
     "Inv1x1Conv",
     "regular_matrix_init",
+    "LogitifyImage",
+    "Flatten",
+    "Squeeze",
 ]
